@@ -140,6 +140,7 @@ The End
 #include "stdafx.h"
 #include <sys/timeb.h>
 #include <ctime>
+#include "saxsaphandler.h"
 #include "msequence.h"
 #include "msequencecollection.h"
 #include "msequenceserver.h"
@@ -849,7 +850,7 @@ bool mreport::sequence(mspectrum &_s,const bool _b,vector<string> &_p,map<string
 				m_ofOut << "<aa type=\"" << _s.m_vseqBest[a].m_vDomains[b].m_vAa[c].m_cRes << "\" at=\"" << _s.m_vseqBest[a].m_vDomains[b].m_vAa[c].m_lPos+1 << "\" ";
 				sprintf(pLine,"%.5lf",_s.m_vseqBest[a].m_vDomains[b].m_vAa[c].m_dMod);
 				m_ofOut << "modified=\"" << pLine << "\" ";
-				if(_s.m_vseqBest[a].m_vDomains[b].m_vAa[c].m_cMut != '\0')	{
+				if(_s.m_vseqBest[a].m_vDomains[b].m_vAa[c].m_cMut != '\0' && _s.m_vseqBest[a].m_vDomains[b].m_vAa[c].m_cMut != _s.m_vseqBest[a].m_vDomains[b].m_vAa[c].m_cRes)	{
 					m_ofOut << "pm=\"" << _s.m_vseqBest[a].m_vDomains[b].m_vAa[c].m_cMut << "\" ";
 				}
 				if(_s.m_vseqBest[a].m_vDomains[b].m_vAa[c].m_strId.size() != 0)	{
