@@ -683,8 +683,10 @@ bool p3mprocess::create_score(const msequence &_s,const size_t _v,const size_t _
 				}
 			}
 			if(fabs(dDelta) > 2.5)	{
-				m_vSpectra[a].m_fScoreNext = m_vSpectra[a].m_fScore;
-				m_vSpectra[a].m_fHyperNext = m_vSpectra[a].m_fHyper;
+				if(m_vSpectra[a].m_fHyper > m_vSpectra[a].m_fScoreNext)	{
+					m_vSpectra[a].m_fScoreNext = m_vSpectra[a].m_fScore;
+					m_vSpectra[a].m_fHyperNext = m_vSpectra[a].m_fHyper;
+				}
 				m_vSpectra[a].m_fScore = fScore;
 				m_vSpectra[a].m_fHyper = fHyper;
 				domValue.m_fScore = fScore;
@@ -716,8 +718,7 @@ bool p3mprocess::create_score(const msequence &_s,const size_t _v,const size_t _
 				m_vSpectra[a].m_vseqBest.push_back(seqValue);
 			}
 		}
-		else if (_p && bIonCheck && fHyper > m_vSpectra[a].m_fHyperNext)
-		{
+		else if(_p && bMassCheck && bIonCheck && fHyper > m_vSpectra[a].m_fHyperNext)	{
 			m_vSpectra[a].m_fScoreNext = fScore;
 			m_vSpectra[a].m_fHyperNext = fHyper;
 		}
